controller property
Optional pre-existing controller. When null, the widget creates and disposes its own controller.
Implementation
final VolvoxGridController? controller;
Optional pre-existing controller. When null, the widget creates and disposes its own controller.
final VolvoxGridController? controller;