ColIndicatorConfig class
- Available extensions
Constructors
-
ColIndicatorConfig({bool? visible, int? defaultRowHeight, int? bandRows, int? background, int? foreground, GridLineStyle? gridLines, int? gridColor, bool? autoSize, bool? allowResize, bool? allowReorder, bool? allowMenu, Iterable<
ColIndicatorRowDef> ? rowDefs, Iterable<ColIndicatorCell> ? cells, ColIndicatorCellModes? cellModes}) -
factory
-
ColIndicatorConfig.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- ColIndicatorConfig.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- allowMenu ↔ bool
-
getter/setter pair
- allowReorder ↔ bool
-
getter/setter pair
- allowResize ↔ bool
-
getter/setter pair
- autoSize ↔ bool
-
getter/setter pair
- background ↔ int
-
getter/setter pair
- bandRows ↔ int
-
getter/setter pair
- cellModes ↔ ColIndicatorCellModes
-
getter/setter pair
-
cells
→ PbList<
ColIndicatorCell> -
no setter
- defaultRowHeight ↔ int
-
getter/setter pair
- foreground ↔ int
-
getter/setter pair
- gridColor ↔ int
-
getter/setter pair
- gridLines ↔ GridLineStyle
-
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setter
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited -
rowDefs
→ PbList<
ColIndicatorRowDef> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unknownFields → UnknownFieldSet
-
no setterinherited
- visible ↔ bool
-
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearAllowMenu(
) → void -
clearAllowReorder(
) → void -
clearAllowResize(
) → void -
clearAutoSize(
) → void -
clearBackground(
) → void -
clearBandRows(
) → void -
clearCellModes(
) → void -
clearDefaultRowHeight(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearForeground(
) → void -
clearGridColor(
) → void -
clearGridLines(
) → void -
clearVisible(
) → void -
clone(
) → ColIndicatorConfig - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(ColIndicatorConfig)) → ColIndicatorConfig -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → ColIndicatorConfig - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureCellModes(
) → ColIndicatorCellModes -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasAllowMenu(
) → bool -
hasAllowReorder(
) → bool -
hasAllowResize(
) → bool -
hasAutoSize(
) → bool -
hasBackground(
) → bool -
hasBandRows(
) → bool -
hasCellModes(
) → bool -
hasDefaultRowHeight(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasForeground(
) → bool -
hasGridColor(
) → bool -
hasGridLines(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasVisible(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited