GridEventTargetFlag class
Bitmask values for GridEventTarget.status_flags. Combined per slot kind; see the GridEventTarget comment for which bits apply where.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → GridEventTargetFlag?
Constants
- GRID_TARGET_FLAG_CHECKED → const GridEventTargetFlag
- GRID_TARGET_FLAG_COLLAPSED → const GridEventTargetFlag
- GRID_TARGET_FLAG_DISABLED → const GridEventTargetFlag
- GRID_TARGET_FLAG_EDITING → const GridEventTargetFlag
- GRID_TARGET_FLAG_EXPANDED → const GridEventTargetFlag
- GRID_TARGET_FLAG_FILTER_ACTIVE → const GridEventTargetFlag
- GRID_TARGET_FLAG_INDETERMINATE → const GridEventTargetFlag
- GRID_TARGET_FLAG_NONE → const GridEventTargetFlag
- GRID_TARGET_FLAG_PINNED → const GridEventTargetFlag
- GRID_TARGET_FLAG_SELECTED → const GridEventTargetFlag
- GRID_TARGET_FLAG_SORT_ASC → const GridEventTargetFlag
- GRID_TARGET_FLAG_SORT_DESC → const GridEventTargetFlag
- GRID_TARGET_FLAG_SUBTOTAL → const GridEventTargetFlag
-
values
→ const List<
GridEventTargetFlag>