CellTextEntry class
Simple row/col/text entry used by setCells batch operations.
Constructors
- CellTextEntry({required int row, required int col, required String text})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited