EditCellStyle class

Resolved style properties for the edit overlay.

Constructors

EditCellStyle({String? fontFamily, double? fontSize, bool bold = false, bool italic = false, double padLeft = 0, double padTop = 0, double padRight = 0, double padBottom = 0})
const

Properties

bold bool
final
fontFamily String?
final
fontSize double?
final
hashCode int
The hash code for this object.
no setterinherited
italic bool
final
padBottom double
final
padLeft double
final
padRight double
final
padTop double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited