RendererBackend enum

Supported rendering backends.

Inheritance
Available extensions

Values

auto → const RendererBackend

Automatic selection (prefers GPU if available).

cpu → const RendererBackend

Software rendering to a pixel buffer.

gpu → const RendererBackend

Hardware-accelerated rendering.

vulkan → const RendererBackend

Explicit Vulkan hardware rendering (Android only).

gles → const RendererBackend

Explicit OpenGL ES hardware rendering (Android only).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RendererBackend>
A constant List of the values in this enum, in order of their declaration.