getSelection method
Get the current selection state, including all returned ranges.
Implementation
Future<SelectionState> getSelection() async {
return VolvoxGridService.GetSelection(_getSelectionRequest);
}
Get the current selection state, including all returned ranges.
Future<SelectionState> getSelection() async {
return VolvoxGridService.GetSelection(_getSelectionRequest);
}