VolvoxGridSubtotalLevel class

A subtotal grouping level used by VolvoxGridController.addSubtotals.

Constructors

VolvoxGridSubtotalLevel({int? groupCol, String caption = '', int backColor = _defaultSubtotalBackColor, int foreColor = _defaultSubtotalForeColor})
const

Properties

backColor int
final
caption String
final
foreColor int
final
groupCol int?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited