VolvoxCellEdit<T> class
Cell-edit details surfaced by VolvoxDataGrid.onCellEdit.
- Annotations
Constructors
Properties
- columnIndex → int
-
Index of the edited column in VolvoxDataGrid.columns.
final
- field → String
-
Field identifier from VolvoxColumn.field of the edited column.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- newText → String
-
Cell text entered by the user.
final
- oldText → String
-
Cell text before the edit.
final
- row → T
-
The row value at rowIndex before the edit.
final
- rowIndex → int
-
Index of the edited row in VolvoxDataGrid.rows.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited