onCellEdit property
Called after the user commits an edit on an VolvoxColumn.editable column. The grid will redraw the new text immediately; mutate the underlying row in this callback to keep your own data in sync.
Implementation
final ValueChanged<VolvoxCellEdit<T>>? onCellEdit;