SelectionMode class
How user selection is interpreted. See engine/src/selection.rs.
FREE (0): Standard rectangular cell-range selection. Single contiguous range (row, col, row_end, col_end). BY_ROW (1): Any click selects the entire row. Internally the selection range spans col 0..i32::MAX. BY_COLUMN (2): Any click selects the entire column. Range spans row 0..i32::MAX. LISTBOX (3): Row-based toggle selection. Tracks selected rows in a HashSet
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → SelectionMode?
Constants
- SELECTION_BY_COLUMN → const SelectionMode
- SELECTION_BY_ROW → const SelectionMode
- SELECTION_FREE → const SelectionMode
- SELECTION_LISTBOX → const SelectionMode
- SELECTION_MULTI_RANGE → const SelectionMode
-
values
→ const List<
SelectionMode>